==> mingw-w64-clang-aarch64-glfw-3.3.9-1-any.pkg.tar.zst: clangarm64/share/doc/glfw/html/search/all_5.js <==
var searchData=
[
  ['bar_20from_20nib_20file_0',['macOS menu bar from nib file',['../news.html#macos_nib_33',1,'']]],
  ['be_20rejected_1',['Gamma ramp size of 256 may be rejected',['../news.html#gamma_ramp_size_33',1,'']]],
  ['behaviors_2',['Context release behaviors',['../news.html#news_31_release',1,'']]],
  ['binaries_3',['With CMake and installed GLFW binaries',['../build_guide.html#build_link_cmake_package',1,'']]],
  ['bit_20masks_4',['Modifier key bit masks',['../news.html#news_30_keymods',1,'']]],
  ['blue_5',['blue',['../struct_g_l_f_wgammaramp.html#acf0c836d0efe29c392fe8d1a1042744b',1,'GLFWgammaramp']]],
  ['bluebits_6',['blueBits',['../struct_g_l_f_wvidmode.html#af310977f58d2e3b188175b6e3d314047',1,'GLFWvidmode']]],
  ['buffer_20swapping_7',['buffer swapping',['../context_guide.html#context_swap',1,'Buffer swapping'],['../window_guide.html#buffer_swap',1,'Buffer swapping']]],
  ['buffered_20framebuffers_8',['Single buffered framebuffers',['../news.html#news_31_single',1,'']]],
  ['buffers_9',['Swapping buffers',['../quick_guide.html#quick_swap_buffers',1,'']]],
  ['build_20files_20with_20cmake_10',['Generating build files with CMake',['../compile_guide.html#compile_generate',1,'']]],
  ['build_20system_11',['CMake build system',['../news.html#news_30_cmake',1,'']]],
  ['build_2edox_12',['build.dox',['../build_8dox.html',1,'']]],
  ['building_20applications_13',['Building applications',['../build_guide.html',1,'']]],
  ['button_20input_14',['Mouse button input',['../input_guide.html#input_mouse_button',1,'']]],
  ['button_20states_15',['Joystick button states',['../input_guide.html#joystick_button',1,'']]],
  ['buttons_16',['buttons',['../struct_g_l_f_wgamepadstate.html#a27e9896b51c65df15fba2c7139bfdb9a',1,'GLFWgamepadstate::buttons'],['../group__gamepad__buttons.html',1,'Gamepad buttons'],['../group__buttons.html',1,'Mouse buttons']]],
  ['by_20scroll_20offsets_17',['Wheel position replaced by scroll offsets',['../moving_guide.html#moving_wheel',1,'']]],
  ['by_20step_18',['Step by step',['../quick_guide.html#quick_steps',1,'']]]
];

==> mingw-w64-clang-aarch64-glfw-3.3.9-2-any.pkg.tar.zst: clangarm64/share/doc/glfw/html/search/all_5.js <==
var searchData=
[
  ['bar_20from_20nib_20file_0',['macOS menu bar from nib file',['../news.html#macos_nib_33',1,'']]],
  ['be_20rejected_1',['Gamma ramp size of 256 may be rejected',['../news.html#gamma_ramp_size_33',1,'']]],
  ['behaviors_2',['Context release behaviors',['../news.html#news_31_release',1,'']]],
  ['binaries_3',['With CMake and installed GLFW binaries',['../build_guide.html#build_link_cmake_package',1,'']]],
  ['bit_20masks_4',['Modifier key bit masks',['../news.html#news_30_keymods',1,'']]],
  ['blue_5',['blue',['../struct_g_l_f_wgammaramp.html#acf0c836d0efe29c392fe8d1a1042744b',1,'GLFWgammaramp']]],
  ['bluebits_6',['blueBits',['../struct_g_l_f_wvidmode.html#af310977f58d2e3b188175b6e3d314047',1,'GLFWvidmode']]],
  ['buffer_20swapping_7',['Buffer swapping',['../context_guide.html#context_swap',1,'Buffer swapping'],['../window_guide.html#buffer_swap',1,'Buffer swapping']]],
  ['buffered_20framebuffers_8',['Single buffered framebuffers',['../news.html#news_31_single',1,'']]],
  ['buffers_9',['Swapping buffers',['../quick_guide.html#quick_swap_buffers',1,'']]],
  ['build_20files_20with_20cmake_10',['Generating build files with CMake',['../compile_guide.html#compile_generate',1,'']]],
  ['build_20system_11',['CMake build system',['../news.html#news_30_cmake',1,'']]],
  ['build_2edox_12',['build.dox',['../build_8dox.html',1,'']]],
  ['building_20applications_13',['Building applications',['../build_guide.html',1,'']]],
  ['button_20input_14',['Mouse button input',['../input_guide.html#input_mouse_button',1,'']]],
  ['button_20states_15',['Joystick button states',['../input_guide.html#joystick_button',1,'']]],
  ['buttons_16',['buttons',['../struct_g_l_f_wgamepadstate.html#a27e9896b51c65df15fba2c7139bfdb9a',1,'GLFWgamepadstate::buttons'],['../group__gamepad__buttons.html',1,'Gamepad buttons'],['../group__buttons.html',1,'Mouse buttons']]],
  ['by_20scroll_20offsets_17',['Wheel position replaced by scroll offsets',['../moving_guide.html#moving_wheel',1,'']]],
  ['by_20step_18',['Step by step',['../quick_guide.html#quick_steps',1,'']]]
];
